VERSION 5.00
Begin VB.UserControl WinExt 
   ClientHeight    =   1965
   ClientLeft      =   0
   ClientTop       =   0
   ClientWidth     =   3090
   ScaleHeight     =   1965
   ScaleWidth      =   3090
End
Attribute VB_Name = "WinExt"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
'************************************************
'* Project: WSHExtend  (c) Gnter Born
'* Version: 2.0
'*
'* Windows Scripting Host-Extensions as ActiveX-Control.
'*************************************************
Option Explicit

Public Function WSHKeyExist(Root As Variant, key As Variant) As Boolean
Attribute WSHKeyExist.VB_Description = "Check the existence of a Registry Key/Value."
' Interface to call ExistKey from the WSH (with Variant type)
' use only for compatibility with Version 1.0
' Root: one of the constants for the root key (see APIDeclarations)
' key:  the key to be checked
' return: key existence (true, false)

 Dim Root1 As Long     ' new data types
 Dim key1 As String

On Error GoTo Error

If Not (IsNumeric(Root)) Then
  MsgBox Root & " illegal value for Root", _
        vbOKOnly, _
        "WSHExtend Error in method WSHKeyExist"
  Exit Function

End If
 
 If (TypeName(key) <> "String") Then
  MsgBox key & " illegal value for parameter key", _
        vbOKOnly, _
        "WSHExtend Error in method WSHKeyExist"
  Exit Function
 End If
 
  Root1 = Root             ' data type conversion
 key1 = key
 If ExistKey(Root1, key1) Then  ' test key
   WSHKeyExist = True
 Else
   WSHKeyExist = False
 End If
 
 Exit Function
Error:  ' Error handling
 MsgBox "Error " & Err.Number, vbOKOnly, _
   "Error in WSHExtend method"
 
End Function

Public Function WSHKeyExist1(Root As Variant, key As Variant) As Boolean
Attribute WSHKeyExist1.VB_Description = "Test the existence of a Registry key/value."
' Interface to call ExistKey from a WSH script
' This method supports the strings "HKCR", "HKCU", "HKLM" and "HKU"
' to identify the Registry branch. This is necessary, because we get
' an overflow, if we call the method from JScript with a 0x8000000 value
' Root: one of the string constants for the root key
' key:  the key to be checked
' return: key existence (true, false)

Dim Root1 As Long     ' new data types
Dim key1 As String

On Error GoTo Error

key1 = key   ' Type conversion

WSHKeyExist1 = False

' Just insert the code for the root key. The constants
' are defined within the APIDeclarations module.
Select Case Root
Case "HKCR"
 Root1 = HKEY_CLASSES_ROOT
Case "HKCU"
 Root1 = HKEY_CURRENT_USER
Case "HKLM"
 Root1 = HKEY_LOCAL_MACHINE
Case "HKU"
 Root1 = HKEY_USERS
Case Else ' #### Error - Root value not implemented ####
  MsgBox Root & " is illegal for parameter root", _
         vbOKOnly, "WSHExtend Error in method WSHKeyExist1"
  Exit Function
End Select

' ### Error checking for key type
 If (TypeName(key) <> "String") Then
  MsgBox key & " illegal value for parameter key", _
        vbOKOnly, _
        "WSHExtend Error in method WSHKeyExist1"
  Exit Function
 End If
 
If ExistKey(Root1, key1) Then ' test key
  WSHKeyExist1 = True
Else
  WSHKeyExist1 = False
End If

Exit Function

Error:  ' Error handling
 MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
   "WSHExtend Error in method WSHKeyExist1"
End Function

Public Function WSHGetTime() As String
Attribute WSHGetTime.VB_Description = "Return current time."
' Just to test, return current time
 WSHGetTime = Time
End Function

Public Function WSHGetDate() As String
Attribute WSHGetDate.VB_Description = "Return current date."
' Just to test, return current date
 WSHGetDate = Date
End Function

Public Function WSHInputBox(Prompt As String, title As String, Default As Variant) As Variant
Attribute WSHInputBox.VB_Description = "Implements the WSHInputBox-Method for WSH-Scripts."
' For JScript: provide a InputBox-Function
' Prompt:  string shown in the input box
' title:   string shown in the input box title bar
' Default: string shown in the edit box
' return:  user input

On Error GoTo Error

 WSHInputBox = InputBox(Prompt, title, Default)
 
Exit Function
 
Error:   ' Error handling
 MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
   "WSHExtend Error in method WSHInputBox"
End Function

Public Sub WSHWait(ticks As Variant)
Attribute WSHWait.VB_Description = "Suspend a script a given time. Ticks define the time in milliseconds."
' For WSH: provide a Wait-Function
' ticks: delay time in milli seconds (must be > 0)

Dim ticks1
On Error GoTo Error

If Not IsNumeric(ticks) Then
 MsgBox ticks & " illegal value for parameter ticks", vbOKOnly, _
   "WSHExtend Error in method WSHWait"
 Exit Sub
Else
 If ticks < 0 Then  ' catch negative values -> infinite wait
   MsgBox ticks & " illegal value for parameter ticks", vbOKOnly, _
   "WSHExtend Error in method WSHWait"
   Exit Sub
 End If
End If
ticks1 = ticks
 
Sleep (ticks)     ' Wait x milli seconds
 
Exit Sub
 
Error:    ' Error handling
 MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
   "WSHExtend Error in method WSHWait"
End Sub

Public Sub WSHBeep(mode As Variant)
Attribute WSHBeep.VB_Description = "Enables a message beep using the PC speaker (mode = 0), or predefined sound files using a sound card (mode 1,2,3,4,5)."
' Beep on PC-Speaker or on Soundcard
' mode: numeric constant for the mode (see below)

 Dim x As Long
 
 On Error GoTo Error
 If Not IsNumeric(mode) Then
   MsgBox mode & " is illegal for parameter mode", vbOKOnly, _
   "WSHExtend Error in method WSHBeep"
   Exit Sub
 End If
 
 Select Case mode
 Case 0
  x = &HFFFFFFFF
 Case 1
  x = MB_ICONASTERISK
 Case 2
  x = MB_ICONEXCLAMATION
 Case 3
  x = MB_ICONHAND
 Case 4
  x = MB_ICONQUESTION
 Case Else
  x = MB_OK
 End Select
   
 MessageBeep (x)            ' Set Sound
 
 Exit Sub
Error:     ' Error handling
 MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
   "WSHExtend Error in method WSHBeep"
End Sub

Public Function WSHShell(path As String, style As Integer) As Variant
Attribute WSHShell.VB_Description = "Launches the application given in path.  Style defines the window style."
' For WSH: Provide the Shell-Function
' path:   Path to executeable Application
' style:  Window style
' vbHide             0   Hide Window
' vbNormalFocus      1   Window get focus.
' vbMinimizedFocus   2   Window minimized and with focus.
' vbMaximizedFocus   3   Window maximized and with focus.
' vbNormalNoFocus    4   Restore Window, don't set focus.
' vbMinimizedNoFocus 6   Window minimized, don't set focus.
' return: Task-ID

On Error GoTo Error
If (TypeName(path) <> "String") Then
 MsgBox path & " illegal value for path", _
        vbOKOnly, _
        "WSHExtend Error in method WSHShell"
 Exit Function
End If
 
If Not IsNumeric(style) Then
  MsgBox style & " illegal value for parameter style", _
        vbOKOnly, _
        "WSHExtend Error in method WSHShell"
  Exit Function
End If
 
WSHShell = Shell(path, style)  ' try to launch application
Exit Function
 
Error:     ' Error handling
MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
       "WSHExtend Error in method WSHBeep"
End Function

Public Function WSHAppActivate(ID As Variant)
Attribute WSHAppActivate.VB_Description = "Activates an Application. The parameter ID contains the process id of the application."
' For WSH: provide an Application-Activate-Function
' ID:  Windows title or Process ID
' return: 0 = OK, not 0 = error code

On Error GoTo Error

If (TypeName(ID) <> "String") And (Not IsNumeric(ID)) Then
 MsgBox ID & " illegal value for parameter ID", _
        vbOKOnly, _
        "WSHExtend Error in method WSHAppActivate"
 Exit Function
End If
 
 AppActivate ID, False        ' try to activate
 WSHAppActivate = 0           ' successful (error code 0)

Exit Function

Error:     ' Error handling
 WSHAppActivate = Err.Number  ' return run-time error number
End Function

Public Sub WSHSendKeys(keys As String, Wait As Boolean)
Attribute WSHSendKeys.VB_Description = "Send keystrokes to the current window."
' For WSH: provide a SendKey-Function
' Parameter:
' keys  a string with the keystrokes
' wait  (true or false)
 
 On Error GoTo Error
   
 SendKeys keys, Wait ' send keys
 Exit Sub
  
Error:   ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHSendKeys"
End Sub

Public Function WSHFindWindow(Winname) As Long
Attribute WSHFindWindow.VB_Description = "Return a window handle. The window title must be submitted in WinName."
' This function retrieves the window handle
' Winname: string with the window title
' return: handle (0 = window not found)

Dim Winname1 As String
On Error GoTo Error

 Winname1 = Winname + vbNullString
 WSHFindWindow = FindWindow(vbNullString, Winname1)
 
Exit Function
Error:    ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHFindWindow"
  WSHFindWindow = 0     ' no handle
End Function

Public Function WSHIsWindow(hwnd) As Boolean
Attribute WSHIsWindow.VB_Description = "Validate the submitted handle whether the window exist."
' Check whether a handle is valid
' hwnd: the handle code
' returns: true/false

On Error GoTo Error
 
If Not IsNumeric(hwnd) Then
  MsgBox hwnd & " is illegal for parameter hwnd", vbOKOnly, _
    "WSHExtend Error in method WSHIsWindow"
  WSHIsWindow = False
  Exit Function              ' abort
End If
 
If IsWindow(hwnd) = 0 Then   ' 0 = false
  WSHIsWindow = False        ' not valid
Else
 WSHIsWindow = True          ' still valid
End If

Exit Function
Error:     ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHIsWindow"
  WSHIsWindow = False        ' return something
End Function

Public Function WSHIsIconic(hwnd) As Boolean
Attribute WSHIsIconic.VB_Description = "Returns true, if the window is minimized. hwnd contains the window handle."
' Check whether a window is minimized
' hwnd: the handle code
' returns: true (minimized)/false

On Error GoTo Error
 
If Not IsNumeric(hwnd) Then
  MsgBox hwnd & " is illegal for parameter hwnd", vbOKOnly, _
    "WSHExtend Error in method WSHIsIconic"
  WSHIsIconic = False
  Exit Function              ' abort
End If

If IsWindow(hwnd) = 0 Then   ' handle valid (0 = false) ?
 MsgBox hwnd & " is not a valid handle", vbOKOnly, _
    "WSHExtend Error in method WSHIsIconic"
  WSHIsIconic = False        ' not valid
  Exit Function
End If
 
If IsIconic(hwnd) = 0 Then   ' 0 = false
  WSHIsIconic = False        ' not minimized
Else
 WSHIsIconic = True          ' minimized
End If

Exit Function
Error:     ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHIsIconic"
  WSHIsIconic = False        ' return something
End Function

Public Function WSHShowWindow(hwnd As Variant, mode As Integer) As Boolean
Attribute WSHShowWindow.VB_Description = "Switches a given window(hwnd is the handle) to the mode defined in the parameter mode."
' Change the visible mode of a given window
' hwnd: window handle
' mode: window mode
' SW_HIDE = 0
' SW_SHOWNORMAL = 1
' SW_SHOWMINIMIZED = 2
' SW_MAXIMIZE = 3
' SW_SHOWNOACTIVATE = 4
' SW_SHOW = 5
' SW_MINIMIZE = 6
' SW_SHOWMINNOACTIVE = 7
' SW_SHOWNA = 8
' SW_RESTORE = 9
' SW_SHOWDEFAULT = 10

Dim hwnd1 As Long

On Error GoTo Error
 
If Not IsNumeric(hwnd) Then
  MsgBox hwnd & " is illegal for parameter hwnd", vbOKOnly, _
    "WSHExtend Error in method WSHShowWindow"
  WSHShowWindow = False
  Exit Function              ' abort
End If

If Not IsNumeric(mode) Then
  MsgBox mode & " is illegal for parameter mode", vbOKOnly, _
    "WSHExtend Error in method WSHShowWindow"
  WSHShowWindow = False
  Exit Function              ' abort
End If

If IsWindow(hwnd) = 0 Then   ' handle valid (0 = false) ?
 MsgBox hwnd & " is not a valid handle", vbOKOnly, _
    "WSHExtend Error in method WSHShowWindow"
  WSHShowWindow = False      ' not valid
  Exit Function
End If
 
hwnd1 = hwnd                 ' type conversion

WSHShowWindow = ShowWindow(hwnd1, mode)
Exit Function

Error:     ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHShowWindow"
  WSHShowWindow = False        ' return something
End Function

Public Function WSHSetForegroundWindow(hwnd As Variant) As Boolean
Attribute WSHSetForegroundWindow.VB_Description = "Switches the defined window into foreground. The handle must be submitted."
' Switch window in foreground
' hwnd: window handle
Dim hwnd1 As Long

On Error GoTo Error

If Not IsNumeric(hwnd) Then
  MsgBox hwnd & " is illegal for parameter hwnd", vbOKOnly, _
    "WSHExtend Error in method WSHSetForegroundWindow"
  WSHSetForegroundWindow = False
  Exit Function              ' abort
End If

If IsWindow(hwnd) = 0 Then   ' handle valid (0 = false) ?
 MsgBox hwnd & " is not a valid handle", vbOKOnly, _
    "WSHExtend Error in method WSHSetForegroundWindow"
  WSHSetForegroundWindow = False      ' not valid
  Exit Function
End If

hwnd1 = hwnd       ' type conversion

WSHSetForegroundWindow = SetForegroundWindow(hwnd1)
Exit Function

Error:     ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHSetForegroundWindow"
  WSHSetForegroundWindow = False        ' return something
End Function

Public Function WSHMoveWindow(hwnd As Variant, x, y, w, h) As Boolean
Attribute WSHMoveWindow.VB_Description = "Set the window size and position. The window handle must be passed in hwnd."
' Move the windows which belongs to the handle
' hwnd: window handle
' x: window left position
' y: window top position
' w: width
' h: height

Dim hwnd1 As Long
On Error GoTo Error
 
If Not IsNumeric(hwnd) Then
  MsgBox hwnd & " is illegal for parameter hwnd", vbOKOnly, _
    "WSHExtend Error in method WSHMoveWindow"
  WSHMoveWindow = False
  Exit Function              ' abort
End If

If IsWindow(hwnd) = 0 Then   ' handle valid (0 = false) ?
 MsgBox hwnd & " is not a valid handle", vbOKOnly, _
    "WSHExtend Error in method WSHMoveWindow"
  WSHMoveWindow = False      ' not valid
  Exit Function
End If
 
hwnd1 = hwnd                 ' type conversion
  
WSHMoveWindow = MoveWindow(hwnd1, x, y, w, h, True)
Exit Function

Error:     ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHMoveWindow"
  WSHMoveWindow = False        ' return something
End Function

Public Function WSHFlashWindow(hwnd As Variant, flag) As Boolean
Attribute WSHFlashWindow.VB_Description = "Flashes the window title. hwnd is the window's handle, flag may be set either to true or false to highligt (or not) the title bar."
' Sets/Resets the highlighted title line
' hwnd = window handle
' flag = flash status (true, false)
' return: current flag value(true, false)

Dim hwnd1 As Long

On Error GoTo Error
 
If Not IsNumeric(hwnd) Then
  MsgBox hwnd & "is illegal for parameter hwnd", vbOKOnly, _
    "WSHExtend Error in method WSHFlashWindow"
  WSHFlashWindow = False  ' return something
End If
 
If Not IsWindow(hwnd) Then
  MsgBox "parameter hwnd " & hwnd & "doesn't points to a valid window", _
         vbOKOnly, "WSHExtend Error in method WSHFlashWindow"
  WSHFlashWindow = False  ' return something
End If
 
hwnd1 = hwnd
If flag Then
 WSHFlashWindow = FlashWindow(hwnd1, True)
Else
 WSHFlashWindow = FlashWindow(hwnd1, False)
End If

Exit Function
Error:     ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHFlashWindow"
  WSHFlashWindow = False  ' return something
End Function

Public Function WSHExitWindows(code As Variant) As Boolean
Attribute WSHExitWindows.VB_Description = "Shutdown, Restart Windwos, Logoff. Code defines the Exit mode."
' Exit Windows
' code: exit mode
' EWX_LOGOFF = 0
' EWX_SHUTDOWN = 1
' EWX_REBOOT = 2

Dim code1 As Long
Dim reserv As Long

On Error GoTo Error
 
 code1 = code
 reserv = 0
 WSHExitWindows = ExitWindowsEx(code, reserv)
 Exit Function
Error:      ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHExitWindows"
  WSHExitWindows = False        ' return something
End Function

Public Function WSHPlaySound(com As String, flag As Long) As Boolean
Attribute WSHPlaySound.VB_Description = "Plays a sound file using the command given in com. Flag defines synchronous/asynchronous output."
' Play Sound

On Error GoTo Error
 WSHPlaySound = sndPlaySound(com, flag)
 
 Exit Function
Error:      ' Error handling
  MsgBox "Run-Time Error number " & Err.Number, vbOKOnly, _
    "WSHExtend Error in method WSHPlaySound"
  WSHPlaySound = False        ' return something
End Function

Public Function WSHMciExecute(com1 As String) As Long
Attribute WSHMciExecute.VB_Description = "Plays a sound file using a command in com1."
' Play Multimedia-file
Dim com As String
com = com1
 WSHMciExecute = mciExecute(com)
End Function

Public Function WSHFileDialog(dr1 As Variant) As Boolean
Attribute WSHFileDialog.VB_Description = "Provides a file dialog. Dr1 is the drive which shall be shown after the dialog is getting invoked."
Dim dr As String
 dr = dr1
 drive = dr          ' init values
 folder = dr
 file = ""
 Dialog.Show (vbModal)
 WSHFileDialog = status
End Function

Public Property Get FileName() As Variant
' FileDialog file name
 FileName = file
End Property

Public Property Get FolderName() As Variant
' FileDialog folder name
 FolderName = folder
End Property

Public Property Get DriveName() As Variant
' FileDialog drive name
 DriveName = drive
End Property

Public Sub WSHAbout()
Attribute WSHAbout.VB_Description = "Displays an About dialog"
Dim txt
 txt = "ActiveX-Control to extend the Windows Scripting Host" + vbCrLf + _
        "with a new WSHExtend object and and new methods." + vbCrLf + _
        "" + vbCrLf + vbCrLf + _
        "http://ourworld.compuserve.com/homepages/Guenter_Born"
 MsgBox txt, vbOKOnly + vbInformation, "(c) Gnter Borns WSH-Extension - Version 2.0"
End Sub

Public Sub WSHAbout1()
Attribute WSHAbout1.VB_Description = "Displays an About message"
 About.Show (vbModal)
End Sub



