'************************************************
' File:     ExceCSV1.vbs (WSH sample in VBScript) 
' Author:   (c) Gnter Born
'
' A modified VBScript sample which demonstrates how to
' import a CSV file (with several separators like commas,
' semicolon, etc.) into a new sheet. We use the import wizard
' to avoid the trouble that CSV files with comma delimiters
' are getting read into the first column (a little bit tricky,
' but I was not able to get Open method to accept the format
' properties - they was ignored). The script requests Excel 2000!
'
' Well, here we go: 
' Launch Excel, add a worksheet, import the CSV file
' select the current worksheet, read some cell values back 
' into the script, print the CSV content and terminate.
'
' Names.csv is a simple text file created with an editor
' using the following structure:
'
' Name:STRING,ID:INT
' Born,123
' Miller,728
' Myers,1334
' McFyer,789
' Thommy,345
'
' The file must be located in the same folder as the script.
'************************************************
Option Explicit
Const vbNormal = 1         ' window style

DIM objXL, objWb, objR, objTab     ' Excel object variables
DIM Title, Text, file, name

Title = "WSH sample - by G. Born"

' here you may set the name of the file to be imported 
file = "Names.csv"    ' must be located in the script folder

' create an Excel object reference
Set objXL = WScript.CreateObject ("Excel.Application")

' set the Excel window properties (not absolutely necessary)
objXL.WindowState = vbNormal ' Normal
objXL.Height = 300           ' height
objXL.Width = 400            ' width
objXL.Left = 40              ' X-Position
objXL.Top = 20               ' Y-Position
objXL.Visible = true         ' show window

' Create new Workbook (needed for import the CSV file=
Set objWb = objXl.WorkBooks.Add 

' Get the first loaded worksheet object of the current workbook
Set objWb = objXL.ActiveWorkBook.WorkSheets(1)
objWb.Activate               ' not absolutely necessary (for CSV)
' Now invoke the import wizard

Set objTab = objWb.QueryTables.Add ("TEXT;"+GetPath + file, objWb.Range("A1"))

' here comes the mumbo jumbo to set all the properties for the wizard
' Oh Microsoft, how do I wish to has a With feature or a possibility to
' pass named arguments to methodes .... 
  objTab.Name = "Names"
  objTab.FieldNames = True
  objTab.RowNumbers = False
  objTab.FillAdjacentFormulas = False
  objTab.PreserveFormatting = True
  objTab.RefreshOnFileOpen = False
  objTab.RefreshStyle = 1  'xlInsertDeleteCells
  objTab.SavePassword = False
  objTab.SaveData = True
  objTab.AdjustColumnWidth = True
  objTab.RefreshPeriod = 0
  objTab.TextFilePromptOnRefresh = False
  objTab.TextFilePlatform = 2  'xlWindows
  objTab.TextFileStartRow = 1
  objTab.TextFileParseType = 1  'xlDelimited
  objTab.TextFileTextQualifier = -4142 ' xlTextQualifierNone
  objTab.TextFileConsecutiveDelimiter = False
  objTab.TextFileTabDelimiter = True               ' ### my delimiters 
  objTab.TextFileSemicolonDelimiter = True
  objTab.TextFileCommaDelimiter = True
  objTab.TextFileSpaceDelimiter = False
  objTab.TextFileColumnDataTypes = Array(1, 1)
  objTab.Refresh False

WScript.Echo "We have loaded the worksheet"

' demonstrate how to read the column header values
Text = "Worksheet " + objWb.name + vbCRLF
Text = Text + "Column titles" + vbCRLF
Text = Text + CStr(objWb.Cells(1, 1).Value) + vbTab
Text = Text + CStr(objWb.Cells(1, 2).Value) + vbCRLF

' show some cell values (using the "hard coded method")
Text = Text + CStr(objWb.Cells(2, 1).Value) + vbTab
Text = Text + CStr(objWb.Cells(2, 2).Value) + vbCRLF
Text = Text + CStr(objWb.Cells(3, 1).Value) + vbTab
Text = Text + CStr(objWb.Cells(3, 2).Value) + vbCRLF
Text = Text + CStr(objWb.Cells(4, 1).Value) + vbTab
Text = Text + CStr(objWb.Cells(4, 2).Value) + vbCRLF

' Show results
MsgBox Text, vbOkOnly+ vbInformation, Title

If (MsgBox ("Print?", vbYesNo + vbQuestion, title) = vbYes ) Then
 objXl.ActiveSheet.PrintOut    ' print Worksheet
 WScript.Echo "We are printing, close after printing"
End If
' I like to prevent the warning message about the unsaved data
' during closing Excel 
objXL.DisplayAlerts = False  ' prevent all message boxes

objXl.Quit()                 ' Quit Excel 
Set objXL = Nothing

WScript.Quit()

'##########################
Function GetPath
' Retrieve the script path
 DIM path
 path = WScript.ScriptFullName  ' Script name
 GetPath = Left(path, InstrRev(path, "\"))
End Function
' End